@@ -26,9 +26,10 @@ import traceback
 
 from pybuilder import __version__
 from pybuilder.core import Logger
-from pybuilder.errors import PybuilderException
+from pybuilder.errors import PyBuilderException
 from pybuilder.execution import ExecutionManager
 from pybuilder.reactor import Reactor
+from pybuilder.scaffolding import start_project
 from pybuilder.terminal import (BOLD, BROWN, RED, GREEN, bold, styled_text,
                                 fg, italic, print_text, print_text_line,
                                 print_error, print_error_line, draw_line)
@@ -37,7 +38,7 @@ from pybuilder.utils import format_timestamp
 PROPERTY_OVERRIDE_PATTERN = re.compile(r'^[a-zA-Z0-9_]+=.*')
 
 
-class CommandLineUsageException(PybuilderException):
+class CommandLineUsageException(PyBuilderException):
 
     def __init__(self, usage, message):
         super(CommandLineUsageException, self).__init__(message)
@@ -89,6 +90,12 @@ def parse_options(args):
                       default=False,
                       help="List tasks")
 
+    parser.add_option("--start-project",
+                      action="store_true",
+                      dest="start_project",
+                      default=False,
+                      help="Initialize a build descriptor and python project structure.")
+
     parser.add_option("-v", "--verbose",
                       action="store_true",
                       dest="verbose",
@@ -286,6 +293,9 @@ def main(*args):
     logger = init_logger(options)
     reactor = init_reactor(logger)
 
+    if options.start_project:
+        return start_project()
+
     if options.list_tasks:
         reactor.prepare_build(property_overrides=options.property_overrides,
                               project_directory=options.project_directory)
@@ -317,7 +327,7 @@ def main(*args):
                 environments=options.environments, tasks=arguments)
 
         except KeyboardInterrupt:
-            raise PybuilderException("Build aborted")
+            raise PyBuilderException("Build aborted")
 
     except Exception as e:
         failure_message = str(e)
